# Machine Learning Model Serving made Efficient in the Cloud

```{eval-rst}
.. meta::
    :description lang=en:
        MOSEC is a high-performance serving framework for ML models, offers dynamic batching and multi-stage pipeline to fully exploit your compute machine.
```

```{note}
{doc}`mosec is licensed under the Apache-2 <license>`.
```

```{include} ../../README.md
```

```{toctree}
---
maxdepth: 2
hidden:
caption: User Guide
---
reference/index
examples/index
```

```{toctree}
---
maxdepth: 2
hidden:
caption: Dev Guide
---
development/index
```

```{toctree}
---
hidden:
caption: Project Links
---

GitHub <https://github.com/mosecorg/mosec>
Discord <https://discord.gg/Jq5vxuH69W>
```

## Indices and tables

- {ref}`genindex`
